.. _api_Shortcuts:

=========
Shortcuts
=========

.. contents::

----------------------------------------------
biomedsheets.shortcuts.TestSampleChildShortcut
----------------------------------------------

.. autoclass:: biomedsheets.shortcuts.TestSampleChildShortcut
    :members:

-----------------------------------------
biomedsheets.shortcuts.NGSLibraryShortcut
-----------------------------------------

.. autoclass:: biomedsheets.shortcuts.NGSLibraryShortcut
    :members:

-----------------------------------------
biomedsheets.shortcuts.TestSampleShortcut
-----------------------------------------

.. autoclass:: biomedsheets.shortcuts.TestSampleShortcut
    :members:

----------------------------------------
biomedsheets.shortcuts.GermlineCaseSheet
----------------------------------------

.. autoclass:: biomedsheets.shortcuts.GermlineCaseSheet
    :members:

--------------------------------------
biomedsheets.shortcuts.CancerCaseSheet
--------------------------------------

.. autoclass:: biomedsheets.shortcuts.CancerCaseSheet
    :members:

----------------------------------
biomedsheets.shortcuts.CancerDonor
----------------------------------

.. autoclass:: biomedsheets.shortcuts.CancerDonor
    :members:


----------------------------------------------
biomedsheets.shortcuts.CancerMatchedSamplePair
----------------------------------------------

.. autoclass:: biomedsheets.shortcuts.CancerMatchedSamplePair
    :members:


--------------------------------------
biomedsheets.shortcuts.CancerBioSample
--------------------------------------

.. autoclass:: biomedsheets.shortcuts.CancerBioSample
    :members:


----------------------------------
biomedsheets.shortcuts.SampleSheet
----------------------------------

.. autoclass:: biomedsheets.shortcuts.GenericSampleSheet
    :members:
